# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation as windows_foundation
import winrt.windows.foundation.collections as windows_foundation_collections
import winui3.microsoft.windows.appnotifications as microsoft_windows_appnotifications

from winui3.microsoft.windows.appnotifications.builder import AppNotificationAudioLooping, AppNotificationButtonStyle, AppNotificationDuration, AppNotificationImageCrop, AppNotificationScenario, AppNotificationSoundEvent

Self = typing.TypeVar('Self')

@typing.final
class AppNotificationBuilder_Static(winrt._winrt.IInspectable_Static):
    # System.Boolean Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::IsUrgentScenarioSupported()
    def is_urgent_scenario_supported(cls) -> bool: ...

@typing.final
class AppNotificationBuilder(winrt.system.Object, metaclass=AppNotificationBuilder_Static):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::AddArgument(System.String,System.String)
    def add_argument(self, key: str, value: str, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::AddButton(Microsoft.Windows.AppNotifications.Builder.AppNotificationButton)
    def add_button(self, value: AppNotificationButton, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::AddComboBox(Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox)
    def add_combo_box(self, value: AppNotificationComboBox, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::AddProgressBar(Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar)
    def add_progress_bar(self, value: AppNotificationProgressBar, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::AddText(System.String)
    def add_text(self, text: str, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::AddText(System.String,Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties)
    def add_text2(self, text: str, properties: AppNotificationTextProperties, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::AddTextBox(System.String)
    def add_text_box(self, id: str, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::AddTextBox(System.String,System.String,System.String)
    def add_text_box2(self, id: str, place_holder_text: str, title: str, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.AppNotification Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::BuildNotification()
    def build_notification(self) -> microsoft_windows_appnotifications.AppNotification: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::MuteAudio()
    def mute_audio(self) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetAppLogoOverride(Windows.Foundation.Uri)
    def set_app_logo_override(self, image_uri: windows_foundation.Uri, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetAppLogoOverride(Windows.Foundation.Uri,Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop)
    def set_app_logo_override2(self, image_uri: windows_foundation.Uri, image_crop: AppNotificationImageCrop, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetAppLogoOverride(Windows.Foundation.Uri,Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop,System.String)
    def set_app_logo_override3(self, image_uri: windows_foundation.Uri, image_crop: AppNotificationImageCrop, alternate_text: str, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetAttributionText(System.String)
    def set_attribution_text(self, text: str, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetAttributionText(System.String,System.String)
    def set_attribution_text2(self, text: str, language: str, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetAudioEvent(Microsoft.Windows.AppNotifications.Builder.AppNotificationSoundEvent)
    def set_audio_event(self, app_notification_sound_event: AppNotificationSoundEvent, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetAudioEvent(Microsoft.Windows.AppNotifications.Builder.AppNotificationSoundEvent,Microsoft.Windows.AppNotifications.Builder.AppNotificationAudioLooping)
    def set_audio_event2(self, app_notification_sound_event: AppNotificationSoundEvent, loop: AppNotificationAudioLooping, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetAudioUri(Windows.Foundation.Uri)
    def set_audio_uri(self, audio_uri: windows_foundation.Uri, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetAudioUri(Windows.Foundation.Uri,Microsoft.Windows.AppNotifications.Builder.AppNotificationAudioLooping)
    def set_audio_uri2(self, audio_uri: windows_foundation.Uri, loop: AppNotificationAudioLooping, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetDuration(Microsoft.Windows.AppNotifications.Builder.AppNotificationDuration)
    def set_duration(self, duration: AppNotificationDuration, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetGroup(System.String)
    def set_group(self, group: str, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetHeroImage(Windows.Foundation.Uri)
    def set_hero_image(self, image_uri: windows_foundation.Uri, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetHeroImage(Windows.Foundation.Uri,System.String)
    def set_hero_image2(self, image_uri: windows_foundation.Uri, alternate_text: str, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetInlineImage(Windows.Foundation.Uri)
    def set_inline_image(self, image_uri: windows_foundation.Uri, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetInlineImage(Windows.Foundation.Uri,Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop)
    def set_inline_image2(self, image_uri: windows_foundation.Uri, image_crop: AppNotificationImageCrop, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetInlineImage(Windows.Foundation.Uri,Microsoft.Windows.AppNotifications.Builder.AppNotificationImageCrop,System.String)
    def set_inline_image3(self, image_uri: windows_foundation.Uri, imagecrop: AppNotificationImageCrop, alternate_text: str, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetScenario(Microsoft.Windows.AppNotifications.Builder.AppNotificationScenario)
    def set_scenario(self, value: AppNotificationScenario, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetTag(System.String)
    def set_tag(self, value: str, /) -> AppNotificationBuilder: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder Microsoft.Windows.AppNotifications.Builder.AppNotificationBuilder::SetTimeStamp(Windows.Foundation.DateTime)
    def set_time_stamp(self, value: datetime.datetime, /) -> AppNotificationBuilder: ...

@typing.final
class AppNotificationButton_Static(winrt._winrt.IInspectable_Static):
    # System.Boolean Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::IsButtonStyleSupported()
    def is_button_style_supported(cls) -> bool: ...
    # System.Boolean Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::IsToolTipSupported()
    def is_tool_tip_supported(cls) -> bool: ...

@typing.final
class AppNotificationButton(winrt.system.Object, metaclass=AppNotificationButton_Static):
    @typing.overload
    def __new__(cls: typing.Type[Self], content: str) -> Self: ...
    @typing.overload
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationButton Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::AddArgument(System.String,System.String)
    def add_argument(self, key: str, value: str, /) -> AppNotificationButton: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationButton Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::SetButtonStyle(Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle)
    def set_button_style(self, value: AppNotificationButtonStyle, /) -> AppNotificationButton: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationButton Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::SetContextMenuPlacement()
    def set_context_menu_placement(self) -> AppNotificationButton: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationButton Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::SetIcon(Windows.Foundation.Uri)
    def set_icon(self, value: windows_foundation.Uri, /) -> AppNotificationButton: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationButton Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::SetInputId(System.String)
    def set_input_id(self, value: str, /) -> AppNotificationButton: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationButton Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::SetInvokeUri(Windows.Foundation.Uri)
    def set_invoke_uri(self, protocol_uri: windows_foundation.Uri, /) -> AppNotificationButton: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationButton Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::SetInvokeUri(Windows.Foundation.Uri,System.String)
    def set_invoke_uri2(self, protocol_uri: windows_foundation.Uri, target_app_id: str, /) -> AppNotificationButton: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationButton Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::SetToolTip(System.String)
    def set_tool_tip(self, value: str, /) -> AppNotificationButton: ...
    # System.String Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::get_ToolTip()
    @_property
    def tool_tip(self) -> str: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::put_ToolTip(System.String)
    @tool_tip.setter
    def tool_tip(self, value: str) -> None: ...
    # System.String Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::get_TargetAppId()
    @_property
    def target_app_id(self) -> str: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::put_TargetAppId(System.String)
    @target_app_id.setter
    def target_app_id(self, value: str) -> None: ...
    # Windows.Foundation.Uri Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::get_InvokeUri()
    @_property
    def invoke_uri(self) -> windows_foundation.Uri: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::put_InvokeUri(Windows.Foundation.Uri)
    @invoke_uri.setter
    def invoke_uri(self, value: windows_foundation.Uri) -> None: ...
    # System.String Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::get_InputId()
    @_property
    def input_id(self) -> str: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::put_InputId(System.String)
    @input_id.setter
    def input_id(self, value: str) -> None: ...
    # Windows.Foundation.Uri Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::get_Icon()
    @_property
    def icon(self) -> windows_foundation.Uri: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::put_Icon(Windows.Foundation.Uri)
    @icon.setter
    def icon(self, value: windows_foundation.Uri) -> None: ...
    # System.Boolean Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::get_ContextMenuPlacement()
    @_property
    def context_menu_placement(self) -> bool: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::put_ContextMenuPlacement(System.Boolean)
    @context_menu_placement.setter
    def context_menu_placement(self, value: bool) -> None: ...
    # System.String Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::get_Content()
    @_property
    def content(self) -> str: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::put_Content(System.String)
    @content.setter
    def content(self, value: str) -> None: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::get_ButtonStyle()
    @_property
    def button_style(self) -> AppNotificationButtonStyle: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::put_ButtonStyle(Microsoft.Windows.AppNotifications.Builder.AppNotificationButtonStyle)
    @button_style.setter
    def button_style(self, value: AppNotificationButtonStyle) -> None: ...
    # Windows.Foundation.Collections.IMap`2<System.String,System.String> Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::get_Arguments()
    @_property
    def arguments(self) -> typing.MutableMapping[str, str]: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationButton::put_Arguments(Windows.Foundation.Collections.IMap`2<System.String,System.String>)
    @arguments.setter
    def arguments(self, value: typing.MutableMapping[str, str]) -> None: ...

@typing.final
class AppNotificationComboBox(winrt.system.Object):
    def __new__(cls: typing.Type[Self], id: str) -> Self: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox::AddItem(System.String,System.String)
    def add_item(self, id: str, content: str, /) -> AppNotificationComboBox: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox::SetSelectedItem(System.String)
    def set_selected_item(self, id: str, /) -> AppNotificationComboBox: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox::SetTitle(System.String)
    def set_title(self, value: str, /) -> AppNotificationComboBox: ...
    # System.String Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox::get_Title()
    @_property
    def title(self) -> str: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox::put_Title(System.String)
    @title.setter
    def title(self, value: str) -> None: ...
    # System.String Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox::get_SelectedItem()
    @_property
    def selected_item(self) -> str: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox::put_SelectedItem(System.String)
    @selected_item.setter
    def selected_item(self, value: str) -> None: ...
    # Windows.Foundation.Collections.IMap`2<System.String,System.String> Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox::get_Items()
    @_property
    def items(self) -> typing.MutableMapping[str, str]: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationComboBox::put_Items(Windows.Foundation.Collections.IMap`2<System.String,System.String>)
    @items.setter
    def items(self, value: typing.MutableMapping[str, str]) -> None: ...

@typing.final
class AppNotificationProgressBar(winrt.system.Object):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::BindStatus()
    def bind_status(self) -> AppNotificationProgressBar: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::BindTitle()
    def bind_title(self) -> AppNotificationProgressBar: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::BindValue()
    def bind_value(self) -> AppNotificationProgressBar: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::BindValueStringOverride()
    def bind_value_string_override(self) -> AppNotificationProgressBar: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::SetStatus(System.String)
    def set_status(self, value: str, /) -> AppNotificationProgressBar: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::SetTitle(System.String)
    def set_title(self, value: str, /) -> AppNotificationProgressBar: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::SetValue(System.Double)
    def set_value(self, value: winrt.system.Double, /) -> AppNotificationProgressBar: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::SetValueStringOverride(System.String)
    def set_value_string_override(self, value: str, /) -> AppNotificationProgressBar: ...
    # System.String Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::get_ValueStringOverride()
    @_property
    def value_string_override(self) -> str: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::put_ValueStringOverride(System.String)
    @value_string_override.setter
    def value_string_override(self, value: str) -> None: ...
    # System.Double Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::get_Value()
    @_property
    def value(self) -> winrt.system.Double: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::put_Value(System.Double)
    @value.setter
    def value(self, value: winrt.system.Double) -> None: ...
    # System.String Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::get_Title()
    @_property
    def title(self) -> str: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::put_Title(System.String)
    @title.setter
    def title(self, value: str) -> None: ...
    # System.String Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::get_Status()
    @_property
    def status(self) -> str: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationProgressBar::put_Status(System.String)
    @status.setter
    def status(self, value: str) -> None: ...

@typing.final
class AppNotificationTextProperties(winrt.system.Object):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties::SetIncomingCallAlignment()
    def set_incoming_call_alignment(self) -> AppNotificationTextProperties: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties::SetLanguage(System.String)
    def set_language(self, value: str, /) -> AppNotificationTextProperties: ...
    # Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties::SetMaxLines(System.Int32)
    def set_max_lines(self, value: winrt.system.Int32, /) -> AppNotificationTextProperties: ...
    # System.Int32 Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties::get_MaxLines()
    @_property
    def max_lines(self) -> winrt.system.Int32: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties::put_MaxLines(System.Int32)
    @max_lines.setter
    def max_lines(self, value: winrt.system.Int32) -> None: ...
    # System.String Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties::get_Language()
    @_property
    def language(self) -> str: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties::put_Language(System.String)
    @language.setter
    def language(self, value: str) -> None: ...
    # System.Boolean Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties::get_IncomingCallAlignment()
    @_property
    def incoming_call_alignment(self) -> bool: ...
    # System.Void Microsoft.Windows.AppNotifications.Builder.AppNotificationTextProperties::put_IncomingCallAlignment(System.Boolean)
    @incoming_call_alignment.setter
    def incoming_call_alignment(self, value: bool) -> None: ...

